@@ -9,22 +9,23 @@ This header file contains definitions for Lambert's Problem
 #ifndef LAMBERT_H
 #define LAMBERT_H
 
-#include "orbit_math_types.h"
+#include "vec_math_types.h"
 
-typedef struct LambertSolution {
-    double v1[3];
-    double v2[3];
+typedef struct LambertSolution
+{
+    Vector3 v1;
+    Vector3 v2;
     double dt;
 } LambertSolution;
 
 // Lambert's Problem
 
-enum TrajectoryType {
+enum TrajectoryType
+{
     PROGRADE,
     RETROGRADE
 };
 
 LambertSolution lambert(Vector3 R1, Vector3 R2, double dt, double mu, enum TrajectoryType type);
 
-
 #endif // LAMBERT_H
\ No newline at end of file
